@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,9 +17,8 @@
 #ifndef SOLARUS_BLOCK_H
 #define SOLARUS_BLOCK_H
 
-#include "solarus/Common.h"
+#include "solarus/core/Common.h"
 #include "solarus/entities/Entity.h"
-#include "solarus/lowlevel/Point.h"
 #include <string>
 
 namespace Solarus {
@@ -27,7 +26,7 @@ namespace Solarus {
 /**
  * \brief A entity that the hero can push or pull.
  *
- * Some blocks can be moved only once or in only one direction.
+ * Some blocks can be moved multiple times or in only one direction.
  */
 class Block: public Entity {
 
@@ -42,7 +41,7 @@ class Block: public Entity {
         const std::string& sprite_name,
         bool can_be_pushed,
         bool can_be_pulled,
-        int maximum_moves
+        int max_moves
     );
 
     EntityType get_type() const override;
@@ -50,6 +49,8 @@ class Block: public Entity {
 
     bool is_obstacle_for(Entity& other) override;
     bool is_hole_obstacle() const override;
+    bool is_deep_water_obstacle() const override;
+    bool is_lava_obstacle() const override;
     bool is_teletransporter_obstacle(Teletransporter& teletransporter) override;
     bool is_hero_obstacle(Hero& hero) override;
     bool is_enemy_obstacle(Enemy& enemy) override;
@@ -71,21 +72,21 @@ class Block: public Entity {
     void set_pushable(bool pushable);
     bool is_pullable() const;
     void set_pullable(bool pullable);
-    int get_maximum_moves() const;
-    void set_maximum_moves(int maximum_moves);
+    int get_max_moves() const;
+    void set_max_moves(int max_moves);
 
   private:
 
     void movement_by_hero_finished();
 
-    int maximum_moves;          /**< indicates whether the block can be pushed
-                                 * (0: none, 1: once: 2: infinite) */
+    int max_moves;              /**< indicates whether the block can be pushed
+                                 * (-1 means infinite) */
     bool sound_played;          /**< true if the block sound was played while pulling it */
     uint32_t when_can_move;     /**< date when the hero can move the block again */
 
     Point last_position;        /**< last position of the block before moving */
     Point initial_position;     /**< position of the block when created */
-    int initial_maximum_moves;  /**< value of maximum_moves when the block was created */
+    int initial_max_moves;      /**< value of maximum_moves when the block was created */
     bool can_be_pushed;         /**< indicates that the hero can push this block */
     bool can_be_pulled;         /**< indicates that the hero can pull this block */
 
