@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 #ifndef SOLARUS_SHOP_TREASURE_H
 #define SOLARUS_SHOP_TREASURE_H
 
-#include "solarus/Common.h"
-#include "solarus/Treasure.h"
-#include "solarus/Sprite.h"
+#include "solarus/core/Common.h"
+#include "solarus/core/Treasure.h"
 #include "solarus/entities/Entity.h"
-#include "solarus/lowlevel/TextSurface.h"
+#include "solarus/graphics/Sprite.h"
+#include "solarus/graphics/TextSurface.h"
 #include <memory>
 #include <string>
 
@@ -76,7 +76,7 @@ class ShopTreasure: public Entity {
     bool notify_action_command_pressed() override;
 
     void update() override;
-    void draw_on_map() override;
+    void built_in_draw(Camera& camera) override;
 
   private:
 
