@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #ifndef SOLARUS_STREAM_ACTION_H
 #define SOLARUS_STREAM_ACTION_H
 
-#include "solarus/Common.h"
+#include "solarus/core/Common.h"
+#include "solarus/core/Point.h"
 #include "solarus/entities/EntityPtr.h"
-#include "solarus/lowlevel/Point.h"
 #include <cstdint>
 #include <memory>
 
@@ -42,6 +42,7 @@ class StreamAction {
     StreamAction(Stream& stream, Entity& entity_moved);
 
     const Stream& get_stream() const;
+    Stream& get_stream();
     const Entity& get_entity_moved() const;
     bool is_active() const;
 
