@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,13 +17,15 @@
 #ifndef SOLARUS_TILE_INFO_H
 #define SOLARUS_TILE_INFO_H
 
-#include "solarus/Common.h"
-#include "solarus/lowlevel/Rectangle.h"
+#include "solarus/core/Common.h"
+#include "solarus/core/Rectangle.h"
+#include <memory>
 #include <string>
 
 namespace Solarus {
 
 class TilePattern;
+class Tileset;
 
 /**
  * \brief Wraps construction parameters of a tile.
@@ -33,7 +35,8 @@ struct TileInfo {
   int layer;
   Rectangle box;
   std::string pattern_id;
-  const TilePattern* pattern = nullptr;
+  std::shared_ptr<TilePattern> pattern;  /**< nullptr if it does not exist in the tileset. */
+  const Tileset* tileset = nullptr;      /**< nullptr means the tileset of the map. */
 };
 
 }
