@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,12 +17,15 @@
 #ifndef SOLARUS_TILESET_H
 #define SOLARUS_TILESET_H
 
-#include "solarus/Common.h"
-#include "solarus/lowlevel/Color.h"
-#include "solarus/lowlevel/SurfacePtr.h"
+#include "solarus/core/Common.h"
+#include "solarus/graphics/Color.h"
+#include "solarus/graphics/Surface.h"
+#include "solarus/graphics/SurfacePtr.h"
 #include <memory>
+#include <mutex>
 #include <string>
 #include <unordered_map>
+#include <vector>
 
 struct lua_State;
 
@@ -42,16 +45,17 @@ class Tileset {
 
     explicit Tileset(const std::string& id);
 
+    bool is_loaded() const;
     void load();
     void unload();
 
     const std::string& get_id() const;
     const Color& get_background_color() const;
-    bool is_loaded() const;
     const SurfacePtr& get_tiles_image() const;
     const SurfacePtr& get_entities_image() const;
-    const TilePattern& get_tile_pattern(const std::string& id) const;
+    std::shared_ptr<TilePattern> get_tile_pattern(const std::string& id) const;
     void set_images(const std::string& other_id);
+    void update();
 
   private:
 
@@ -60,12 +64,22 @@ class Tileset {
         const TilePatternData& pattern_data
     );
 
-    const std::string id;                             /**< id of the tileset */
-    std::unordered_map<std::string, std::unique_ptr<TilePattern>>
-        tile_patterns;                                /**< tile patterns in this tileset */
-    Color background_color;                           /**< background color of the tileset */
-    SurfacePtr tiles_image;                           /**< image from which the tile patterns are extracted */
-    SurfacePtr entities_image;                        /**< image from which the skin-dependent entities are extracted */
+    const std::string id;          /**< Id of the tileset. */
+    std::unordered_map<std::string, std::shared_ptr<TilePattern>>
+        tile_patterns;             /**< Tile patterns in this tileset. */
+    std::vector<TilePattern*>
+        animated_tile_patterns;    /**< Subset of animated patterns. */
+    Color background_color;        /**< Background color of the tileset. */
+    mutable SDL_Surface_UniquePtr
+        tiles_image_soft;          /**< Image from which the tile patterns are extracted. */
+    mutable SurfacePtr
+        tiles_image;               /**< Image from which the tile patterns are extracted. */
+    mutable SDL_Surface_UniquePtr
+         entities_image_soft;      /**< Image from which the tileset-dependent sprites are. */
+    mutable SurfacePtr
+         entities_image;           /**< Image from which the tileset-dependent sprites are. */
+    bool loaded;                   /**< Whether the tileset is loaded. */
+    std::mutex load_mutex;         /**< Lock to protect concurrent tileset loading. */
 
 };
 
