@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 #ifndef SOLARUS_HERO_CARRYING_STATE_H
 #define SOLARUS_HERO_CARRYING_STATE_H
 
+#include "solarus/core/Common.h"
 #include "solarus/hero/PlayerMovementState.h"
 #include <memory>
 
@@ -39,9 +40,9 @@ class Hero::CarryingState: public Hero::PlayerMovementState {
     void set_suspended(bool suspended) override;
     void update() override;
     void notify_action_command_pressed() override;
-    bool can_start_sword() const override;
-    bool can_use_shield() const override;
-    bool can_take_stairs() const override;
+    bool get_can_start_sword() const override;
+    bool get_can_use_shield() const override;
+    bool get_can_take_stairs() const override;
     void set_animation_stopped() override;
     void set_animation_walking() override;
     std::shared_ptr<CarriedObject> get_carried_object() const override;
