@@ -1,34 +1,35 @@
 /*
- * Copyright (C) 2006-2015 Christopho, Solarus - http://www.solarus-games.org
- * 
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
+ *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * Solarus is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef SOLARUS_HERO_FALLING_STATE_H
 #define SOLARUS_HERO_FALLING_STATE_H
 
-#include "solarus/hero/State.h"
+#include "solarus/core/Common.h"
+#include "solarus/hero/HeroState.h"
 
 namespace Solarus {
 
 /**
  * \brief The state "Falling" of the hero.
  */
-class Hero::FallingState: public Hero::State {
+class Hero::FallingState: public HeroState {
 
   public:
 
-    FallingState(Hero& hero);
+    explicit FallingState(Hero& hero);
 
     virtual void start(const State* previous_state) override;
     virtual void stop(const State* next_state) override;
