@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 #ifndef SOLARUS_HERO_JUMPING_STATE_H
 #define SOLARUS_HERO_JUMPING_STATE_H
 
+#include "solarus/core/Common.h"
 #include "solarus/hero/HeroState.h"
 #include <memory>
 
@@ -39,30 +40,30 @@ class Hero::JumpingState: public HeroState {
         bool with_sound
     );
 
-    virtual void start(const State* previous_state) override;
-    virtual void stop(const State* next_state) override;
-    virtual void set_map(Map& map) override;
-    virtual void update() override;
-    virtual void set_suspended(bool suspended) override;
-    virtual void notify_layer_changed() override;
-    virtual int get_wanted_movement_direction8() const override;
-    virtual bool can_start_gameover_sequence() const override;
-    virtual bool is_touching_ground() const override;
-    virtual bool is_stairs_obstacle(const Stairs& stairs) const override;
-    virtual bool is_sensor_obstacle(const Sensor& sensor) const override;
-    virtual bool is_separator_obstacle(const Separator& separator) const override;
-    virtual bool can_avoid_deep_water() const override;
-    virtual bool can_avoid_hole() const override;
-    virtual bool can_avoid_ice() const override;
-    virtual bool can_avoid_lava() const override;
-    virtual bool can_avoid_prickle() const override;
-    virtual bool can_avoid_teletransporter() const override;
-    virtual bool can_avoid_stream(const Stream& stream) const override;
-    virtual bool can_avoid_sensor() const override;
-    virtual bool can_avoid_switch() const override;
-    virtual bool can_be_hurt(Entity* attacker) const override;
-    virtual std::shared_ptr<CarriedObject> get_carried_object() const override;
-    virtual CarriedObject::Behavior get_previous_carried_object_behavior() const override;
+    void start(const State* previous_state) override;
+    void stop(const State* next_state) override;
+    void set_map(Map& map) override;
+    void update() override;
+    void set_suspended(bool suspended) override;
+    void notify_layer_changed() override;
+    int get_wanted_movement_direction8() const override;
+    bool can_start_gameover_sequence() const override;
+    bool is_touching_ground() const override;
+    bool is_stairs_obstacle(Stairs& stairs) override;
+    bool is_sensor_obstacle(Sensor& sensor) override;
+    bool is_separator_obstacle(Separator& separator) override;
+    bool can_avoid_deep_water() const override;
+    bool can_avoid_hole() const override;
+    bool can_avoid_ice() const override;
+    bool can_avoid_lava() const override;
+    bool can_avoid_prickle() const override;
+    bool can_avoid_teletransporter() const override;
+    bool can_avoid_stream(const Stream& stream) const override;
+    bool can_avoid_sensor() const override;
+    bool can_avoid_switch() const override;
+    bool get_can_be_hurt(Entity* attacker) override;
+    std::shared_ptr<CarriedObject> get_carried_object() const override;
+    CarriedObject::Behavior get_previous_carried_object_behavior() const override;
 
   private:
 
