@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 #ifndef SOLARUS_HERO_PULLING_STATE_H
 #define SOLARUS_HERO_PULLING_STATE_H
 
+#include "solarus/core/Common.h"
 #include "solarus/hero/HeroState.h"
 #include <memory>
 
@@ -33,25 +34,25 @@ class Hero::PullingState: public HeroState {
 
     explicit PullingState(Hero& hero);
 
-    virtual void start(const State* previous_state) override;
-    virtual void stop(const State* next_state) override;
-    virtual void update() override;
-    virtual void notify_grabbed_entity_collision() override;
-    virtual void notify_movement_finished() override;
-    virtual void notify_position_changed() override;
-    virtual void notify_obstacle_reached() override;
-    virtual bool is_grabbing_or_pulling() const override;
-    virtual bool is_moving_grabbed_entity() const override;
-    virtual bool is_shallow_water_obstacle() const override;
-    virtual bool is_deep_water_obstacle() const override;
-    virtual bool is_hole_obstacle() const override;
-    virtual bool is_lava_obstacle() const override;
-    virtual bool is_prickle_obstacle() const override;
-    virtual bool is_stream_obstacle(const Stream& stream) const override;
-    virtual bool is_separator_obstacle(const Separator& separator) const override;
+    void start(const State* previous_state) override;
+    void stop(const State* next_state) override;
+    void update() override;
+    void notify_grabbed_entity_collision() override;
+    void notify_movement_finished() override;
+    void notify_position_changed() override;
+    void notify_obstacle_reached() override;
+    bool is_grabbing_or_pulling() const override;
+    bool is_moving_grabbed_entity() const override;
+    bool is_shallow_water_obstacle() const override;
+    bool is_deep_water_obstacle() const override;
+    bool is_hole_obstacle() const override;
+    bool is_lava_obstacle() const override;
+    bool is_prickle_obstacle() const override;
+    bool is_stream_obstacle(Stream& stream) override;
+    bool is_separator_obstacle(Separator& separator) override;
 
-    virtual bool can_be_hurt(Entity* attacker) const override;
-    virtual bool can_pick_treasure(EquipmentItem& item) const override;
+    bool get_can_be_hurt(Entity* attacker) override;
+    bool get_can_pick_treasure(EquipmentItem& item) const override;
 
   private:
 
