@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 #ifndef SOLARUS_HERO_SPIN_ATTACK_STATE_H
 #define SOLARUS_HERO_SPIN_ATTACK_STATE_H
 
+#include "solarus/core/Common.h"
 #include "solarus/entities/EntityState.h"
 
 namespace Solarus {
@@ -30,26 +31,26 @@ class Hero::SpinAttackState: public HeroState {
 
     explicit SpinAttackState(Hero& hero);
 
-    virtual void start(const State* previous_state) override;
-    virtual void stop(const State* next_state) override;
-    virtual void update() override;
-    virtual bool can_sword_hit_crystal() const override;
-    virtual bool can_be_hurt(Entity* attacker) const override;
-    virtual bool can_pick_treasure(EquipmentItem& item) const override;
-    virtual bool is_cutting_with_sword(Entity& entity) override;
-    virtual int get_sword_damage_factor() const override;
-    virtual bool is_deep_water_obstacle() const override;
-    virtual bool is_hole_obstacle() const override;
-    virtual bool is_lava_obstacle() const override;
-    virtual bool is_prickle_obstacle() const override;
-    virtual bool is_teletransporter_obstacle(const Teletransporter& teletransporter) const override;
-    virtual bool is_separator_obstacle(const Separator& separator) const override;
-    virtual void notify_obstacle_reached() override;
-    virtual void notify_attacked_enemy(
+    void start(const State* previous_state) override;
+    void stop(const State* next_state) override;
+    void update() override;
+    bool can_sword_hit_crystal() const override;
+    bool get_can_be_hurt(Entity* attacker) override;
+    bool get_can_pick_treasure(EquipmentItem& item) const override;
+    bool is_cutting_with_sword(Entity& entity) override;
+    int get_sword_damage_factor() const override;
+    bool is_deep_water_obstacle() const override;
+    bool is_hole_obstacle() const override;
+    bool is_lava_obstacle() const override;
+    bool is_prickle_obstacle() const override;
+    bool is_teletransporter_obstacle(Teletransporter& teletransporter) override;
+    bool is_separator_obstacle(Separator& separator) override;
+    void notify_obstacle_reached() override;
+    void notify_attacked_enemy(
         EnemyAttack attack,
         Enemy& victim,
-        const Sprite* victim_sprite,
-        EnemyReaction::Reaction& result,
+        Sprite* victim_sprite,
+        const EnemyReaction::Reaction& result,
         bool killed
     ) override;
 
