@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2016 Christopho, Solarus - http://www.solarus-games.org
+ * Copyright (C) 2006-2018 Christopho, Solarus - http://www.solarus-games.org
  *
  * Solarus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #ifndef SOLARUS_EXPORTABLE_TO_LUA_H
 #define SOLARUS_EXPORTABLE_TO_LUA_H
 
-#include "solarus/Common.h"
+#include "solarus/core/Common.h"
 #include <memory>
 #include <string>
 
@@ -45,12 +45,7 @@ class ExportableToLua:
     void set_known_to_lua(bool known_to_lua);
     bool is_with_lua_table() const;
     void set_with_lua_table(bool with_lua_table);
-
-    /**
-     * \brief Returns the name identifying this type in Lua.
-     * \return the name identifying this type in Lua
-     */
-    virtual const std::string& get_lua_type_name() const = 0;
+    virtual const std::string& get_lua_type_name() const;
 
   private:
 
